@@ -349,8 +349,15 @@ impl PublicKey for PubKeyEnum {
     }
 }
 
+pub(crate) mod inner {
+    #[doc(hidden)]
+    pub trait KeyPairInner {
+        fn scalar_bytes_without_normalization(&self) -> [u8; 32];
+    }
+}
+
 /// Define the operations that can be performed on a cryptographic key pair.
-pub trait KeyPair: Clone + Display + Debug + PartialEq + Eq {
+pub trait KeyPair: Clone + Display + Debug + inner::KeyPairInner + PartialEq + Eq {
     /// Seed
     type Seed: AsRef<[u8]>;
     /// Signator type of associated cryptosystem.
@@ -423,6 +430,18 @@ impl Display for KeyPairEnum {
     }
 }
 
+impl inner::KeyPairInner for KeyPairEnum {
+    fn scalar_bytes_without_normalization(&self) -> [u8; 32] {
+        match self {
+            KeyPairEnum::Ed25519(ref ed25519_keypair) => {
+                ed25519_keypair.scalar_bytes_without_normalization()
+            }
+            #[cfg(feature = "bip32-ed25519")]
+            KeyPairEnum::Bip32Ed25519(ref keypair) => keypair.scalar_bytes_without_normalization(),
+        }
+    }
+}
+
 impl KeyPair for KeyPairEnum {
     type Seed = Seed32;
     type Signator = SignatorEnum;
